summaryrefslogtreecommitdiffstats
path: root/kutils/ksettings/dispatcher.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /kutils/ksettings/dispatcher.h
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kutils/ksettings/dispatcher.h')
-rw-r--r--kutils/ksettings/dispatcher.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kutils/ksettings/dispatcher.h b/kutils/ksettings/dispatcher.h
index c04a41b99..fa0c9e6c9 100644
--- a/kutils/ksettings/dispatcher.h
+++ b/kutils/ksettings/dispatcher.h
@@ -29,7 +29,7 @@ class TQSignal;
class TQStrList;
template<class T> class KStaticDeleter;
class TDEInstance;
-class KConfig;
+class TDEConfig;
namespace KSettings
{
@@ -39,7 +39,7 @@ namespace KSettings
* @short Dispatch change notifications from the KCMs to the program.
*
* Since your program does not have direct control over the KCMs that get loaded
- * into the KConfigureDialog you need a way to get notified. This is what you
+ * into the TDEConfigureDialog you need a way to get notified. This is what you
* do:
* \code
* Dispatcher::self()->registerInstance( instance(), this, TQT_SLOT( loadSettings() ) );
@@ -74,9 +74,9 @@ class KUTILS_EXPORT Dispatcher : public TQObject
void registerInstance( TDEInstance * instance, TQObject * recv, const char * slot );
/**
* @return the KConfig object that belongs to the instanceName
*/
- KConfig * configForInstanceName( const TQCString & instanceName );
+ TDEConfig * configForInstanceName( const TQCString & instanceName );
/**
* @return a list of all the instance names that are currently
@@ -100,10 +100,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
void reparseConfiguration( const TQCString & instanceName );
/**
* When this slot is called the KConfig objects of all the registered
* instances are sync()ed. This is usefull when some other KConfig
* objects will read/write from/to the same config file, so that you
* can first write out the current state of the KConfig objects.
*/
void syncConfiguration();
@@ -74,9 +74,9 @@ class KUTILS_EXPORT Dispatcher : public TQObject
void registerInstance( TDEInstance * instance, TQObject * recv, const char * slot );
/**
- * @return the KConfig object that belongs to the instanceName
+ * @return the TDEConfig object that belongs to the instanceName
*/
@@ -100,10 +100,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
void reparseConfiguration( const TQCString & instanceName );
/**
- * When this slot is called the KConfig objects of all the registered
- * instances are sync()ed. This is usefull when some other KConfig
+ * When this slot is called the TDEConfig objects of all the registered
+ * instances are sync()ed. This is usefull when some other TDEConfig
* objects will read/write from/to the same config file, so that you
@@ -100,10 +100,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
* objects will read/write from/to the same config file, so that you
- * can first write out the current state of the KConfig objects.
+ * can first write out the current state of the TDEConfig objects.
*/
void syncConfiguration();